## 交易日历

接口：trade_cal，可以通过数据工具调试和查看数据。

描述：获取各大交易所交易日历数据,默认提取的是上交所

积分：需2000积分

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| exchange | str | N | 交易所 SSE上交所,SZSE深交所,CFFEX 中金所,SHFE 上期所,CZCE 郑商所,DCE 大商所,INE 上能源 |
| start_date | str | N | 开始日期 （格式：YYYYMMDD 下同） |
| end_date | str | N | 结束日期 |
| is_open | str | N | 是否交易 '0'休市 '1'交易 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| exchange | str | Y | 交易所 SSE上交所 SZSE深交所 |
| cal_date | str | Y | 日历日期 |
| is_open | str | Y | 是否交易 0休市 1交易 |
| pretrade_date | str | Y | 上一个交易日 |

接口示例

```python
pro = ts.pro_api()


df = pro.trade_cal(exchange='', start_date='20180101', end_date='20181231')
```

或者

```python
df = pro.query('trade_cal', start_date='20180101', end_date='20181231')
```

数据样例

```python
exchange  cal_date  is_open
0           SSE  20180101        0
```